fnss.traffic.eventscheduling.write_event_schedule — FNSS 0.7.0 documentation

# fnss.traffic.eventscheduling.write_event_schedule

`write_event_schedule`(event_schedule, path, encoding='utf-8', prettyprint=True)

  Write an event schedule object to an XML file.

  Parameters: | event_schedule : EventSchedule The event schedule to write path : str The path of the output XML file encoding : str, optional The desired encoding of the output file prettyprint : bool, optional Specify whether the XML file should be written with indentation for improved human readability